==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/is.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Merki",
    "Update" : "Uppfæra",
    "Create" : "Búa til",
    "Select tag…" : "Veldu merki...",
    "Tagged files" : "Merktar skrár",
    "Select tags to filter by" : "Veldu merki til að sía eftir",
    "No tags found" : "Engin merki fundust",
    "Please select tags to filter by" : "Veldu merki til að sía eftir",
    "No files found for the selected tags" : "Engar skrár fundust með völdum merkjum",
    "Added system tag %1$s" : "Bætti við kerfismerkinu %1$s",
    "Added system tag {systemtag}" : "Bætti við kerfismerkinu {systemtag}",
    "%1$s added system tag %2$s" : "%1$s bætti við kerfismerkinu %2$s",
    "{actor} added system tag {systemtag}" : "{actor} bætti við kerfismerkinu {systemtag}",
    "Removed system tag %1$s" : "Fjarlægði kerfismerkið %1$s",
    "Removed system tag {systemtag}" : "Fjarlægði kerfismerkið {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s fjarlægði kerfismerkið %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} fjarlægði kerfismerkið {systemtag}",
    "You created system tag %1$s" : "Þú bjóst til kerfismerkið %1$s",
    "You created system tag {systemtag}" : "Þú bjóst til kerfismerkið {systemtag}",
    "%1$s created system tag %2$s" : "%1$s bjó til kerfismerkið %2$s",
    "{actor} created system tag {systemtag}" : "{actor} bjó til kerfismerkið {systemtag}",
    "You deleted system tag %1$s" : "Þú eyddir kerfismerkinu %1$s",
    "You deleted system tag {systemtag}" : "Þú eyddir kerfismerkinu {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eyddi kerfismerkinu %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eyddi kerfismerkinu {systemtag}",
    "You updated system tag %2$s to %1$s" : "Þú uppfærðir kerfismerkið %1$s í %2$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Þú uppfærðir kerfismerkið {oldsystemtag} í {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uppfærði kerfismerkið %3$s í %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uppfærði kerfismerkið {oldsystemtag} í {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Þú bættir við kerfismerkinu %1$s í %2$s",
    "You added system tag {systemtag} to {file}" : "Þú bættir við kerfismerkinu {systemtag} í {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s bætti við kerfismerkinu %3$s í %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} bætti við kerfismerkinu {systemtag} í {file}",
    "You removed system tag %2$s from %1$s" : "Þú fjarlægðir kerfismerkið %2$s af %1$s",
    "You removed system tag {systemtag} from {file}" : "Þú fjarlægðir kerfismerkið {systemtag} af {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s fjarlægði kerfismerkið %3$s af %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} fjarlægði kerfismerkið {systemtag} af {file}",
    "%s (restricted)" : "%s (takmarkaður aðgangur)",
    "%s (invisible)" : "%s (ósýnilegt)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Kerfismerkjum</strong> á skrá hefur verið breytt",
    "Collaborative tags" : "Samstarfsmerkingar",
    "Name" : "Heiti",
    "Delete" : "Eyða",
    "Public" : "Opinbert",
    "Restricted" : "Takmarkað",
    "Invisible" : "Ósýnilegt",
    "Reset" : "Endurstilla",
    "No files in here" : "Engar skrár hér",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Size" : "Stærð",
    "Modified" : "Breytt"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/is.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Merki",
    "Update" : "Uppfæra",
    "Create" : "Búa til",
    "Select tag…" : "Veldu merki...",
    "Tagged files" : "Merktar skrár",
    "Select tags to filter by" : "Veldu merki til að sía eftir",
    "No tags found" : "Engin merki fundust",
    "Please select tags to filter by" : "Veldu merki til að sía eftir",
    "No files found for the selected tags" : "Engar skrár fundust með völdum merkjum",
    "Added system tag %1$s" : "Bætti við kerfismerkinu %1$s",
    "Added system tag {systemtag}" : "Bætti við kerfismerkinu {systemtag}",
    "%1$s added system tag %2$s" : "%1$s bætti við kerfismerkinu %2$s",
    "{actor} added system tag {systemtag}" : "{actor} bætti við kerfismerkinu {systemtag}",
    "Removed system tag %1$s" : "Fjarlægði kerfismerkið %1$s",
    "Removed system tag {systemtag}" : "Fjarlægði kerfismerkið {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s fjarlægði kerfismerkið %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} fjarlægði kerfismerkið {systemtag}",
    "You created system tag %1$s" : "Þú bjóst til kerfismerkið %1$s",
    "You created system tag {systemtag}" : "Þú bjóst til kerfismerkið {systemtag}",
    "%1$s created system tag %2$s" : "%1$s bjó til kerfismerkið %2$s",
    "{actor} created system tag {systemtag}" : "{actor} bjó til kerfismerkið {systemtag}",
    "You deleted system tag %1$s" : "Þú eyddir kerfismerkinu %1$s",
    "You deleted system tag {systemtag}" : "Þú eyddir kerfismerkinu {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eyddi kerfismerkinu %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eyddi kerfismerkinu {systemtag}",
    "You updated system tag %2$s to %1$s" : "Þú uppfærðir kerfismerkið %1$s í %2$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Þú uppfærðir kerfismerkið {oldsystemtag} í {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s uppfærði kerfismerkið %3$s í %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} uppfærði kerfismerkið {oldsystemtag} í {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Þú bættir við kerfismerkinu %1$s í %2$s",
    "You added system tag {systemtag} to {file}" : "Þú bættir við kerfismerkinu {systemtag} í {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s bætti við kerfismerkinu %3$s í %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} bætti við kerfismerkinu {systemtag} í {file}",
    "You removed system tag %2$s from %1$s" : "Þú fjarlægðir kerfismerkið %2$s af %1$s",
    "You removed system tag {systemtag} from {file}" : "Þú fjarlægðir kerfismerkið {systemtag} af {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s fjarlægði kerfismerkið %3$s af %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} fjarlægði kerfismerkið {systemtag} af {file}",
    "%s (restricted)" : "%s (takmarkaður aðgangur)",
    "%s (invisible)" : "%s (ósýnilegt)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Kerfismerkjum</strong> á skrá hefur verið breytt",
    "Collaborative tags" : "Samstarfsmerkingar",
    "Select tag …" : "Veldu merki ...",
    "Name" : "Heiti",
    "Public" : "Opinbert",
    "Restricted" : "Takmarkað",
    "Invisible" : "Ósýnilegt",
    "Delete" : "Eyða",
    "Reset" : "Endurstilla",
    "No files in here" : "Engar skrár hér",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "Create and edit collaborative tags. These tags affect all users." : "Búðu til og breyttu merkjum fyrir samstarfsupplýsingar. Þessi merki hafa áhrif á alla notendur."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
